import java.util.Scanner;

// Implements a simple random linear congruential number generator. Although 
// the implementation is not secure as we can predict the values given a seed, 
// it is not good where unpredictable randomness is desired. However, it should
// output uniformly distributed numbers, which can be used for scientific 
// stochastic applications. 

public class MyRandom {
    private long seed;
    
    public MyRandom(long seed) {
        this.seed = seed;
    }
    
    public long next(int bits) {
        if (bits > 63) {
            throw new IllegalArgumentException();
        }
        
        // the multiplicand is prime, the addend is some arbitrary number 
        seed = seed * 0xfb09bfc5f5336fb3L + 0x528bf28151dc74dL;
        return (long) (seed >>> (64 - bits));
    }
    
    
    public static void main(String... args) {
        Scanner sc = new Scanner(System.in);
        MyRandom rand = new MyRandom(0x2015_04_25);
        
        while (sc.hasNextLine()) {
            sc.nextLine();
            double rn = rand.next(53) / ((double) (1L << 53));
            System.out.println(rn);
        }
    }
    
    
}